==> gulid-0.0.1.tar: src/examples@example1.erl <==
-module(examples@example1).
-compile([no_auto_import, nowarn_unused_vars, nowarn_unused_function, nowarn_nomatch]).

-export([main/0]).

-file("/Users/svava/Projects/Gleam/ulid/src/examples/example1.gleam", 8).
-spec main() -> nil.
main() ->
    Ulid_str = gulid:new_as_string(),
    gleam@io:println(<<"ULID is "/utf8, Ulid_str/binary>>),
    To_string = gulid:to_string_function(),
    Bunch_of_ulids = gleam@list:map(
        [gulid:new(), gulid:new(), gulid:new(), gulid:new(), gulid:new()],
        To_string
    ),
    gleam@io:println(<<"A bunch of ULIDs:"/utf8>>),
    gleam@io:debug(Bunch_of_ulids),
    From_string = gulid:from_string_function(),
    _assert_subject = From_string(<<"01J9HSAQG7YR6Z16SS7ZTH26WQ"/utf8>>),
    {ok, Ulid} = case _assert_subject of
        {ok, _} -> _assert_subject;
        _assert_fail ->
            erlang:error(#{gleam_error => let_assert,
                        message => <<"Pattern match failed, no pattern matched the value."/utf8>>,
                        value => _assert_fail,
                        module => <<"examples/example1"/utf8>>,
                        function => <<"main"/utf8>>,
                        line => 30})
    end,
    gleam@io:println(<<"Quick and dirty ULID is"/utf8>>),
    gleam@io:debug(Ulid),
    gleam@io:println(<<"A more properly parsed ULID is"/utf8>>),
    case From_string(<<"01J9HS6WA9ZBA045WTNYWAGPM5"/utf8>>) of
        {ok, Ulid@1} ->
            gleam@io:debug(Ulid@1),
            nil;

        {error, {invalid_length, Error}} ->
            gleam@io:println(<<"Oh, noes: "/utf8, Error/binary>>);

        {error, {decode_error, Error}} ->
            gleam@io:println(<<"Oh, noes: "/utf8, Error/binary>>)
    end.

==> gulid-0.0.3.tar: src/examples@example1.erl <==
-module(examples@example1).
-compile([no_auto_import, nowarn_unused_vars, nowarn_unused_function, nowarn_nomatch]).

-export([main/0]).

-file("/Users/svava/Projects/Gleam/ulid/src/examples/example1.gleam", 8).
-spec main() -> list(binary()).
main() ->
    Ulid_str = gulid:new_as_string(),
    gleam@io:println(<<"ULID is "/utf8, Ulid_str/binary>>),
    To_string = gulid:to_string_function(),
    Bunch_of_ulids = gleam@list:map(
        [gulid:new(), gulid:new(), gulid:new(), gulid:new(), gulid:new()],
        To_string
    ),
    gleam@io:println(<<"A bunch of ULIDs:"/utf8>>),
    gleam@io:debug(Bunch_of_ulids),
    From_string = gulid:from_string_function(),
    _assert_subject = From_string(<<"01J9HSAQG7YR6Z16SS7ZTH26WQ"/utf8>>),
    {ok, Ulid} = case _assert_subject of
        {ok, _} -> _assert_subject;
        _assert_fail ->
            erlang:error(#{gleam_error => let_assert,
                        message => <<"Pattern match failed, no pattern matched the value."/utf8>>,
                        value => _assert_fail,
                        module => <<"examples/example1"/utf8>>,
                        function => <<"main"/utf8>>,
                        line => 30})
    end,
    gleam@io:println(<<"Quick and dirty ULID is"/utf8>>),
    gleam@io:debug(Ulid),
    gleam@io:println(<<"A more properly parsed ULID is"/utf8>>),
    case From_string(<<"01J9HS6WA9ZBA045WTNYWAGPM5"/utf8>>) of
        {ok, Ulid@1} ->
            gleam@io:debug(Ulid@1),
            nil;

        {error, {invalid_length, Error}} ->
            gleam@io:println(<<"Oh, noes, the error: "/utf8, Error/binary>>);

        {error, {decode_error, Error}} ->
            gleam@io:println(<<"Oh, noes, the error: "/utf8, Error/binary>>)
    end,
    gleam@io:println(<<"Generating 10 monotonic ULIDs"/utf8>>),
    _pipe = gleam@list:range(0, 9),
    _pipe@1 = gleam@list:scan(
        _pipe,
        gulid:new(),
        fun(Ulid@2, _) -> gulid:new_monotonic(Ulid@2) end
    ),
    _pipe@2 = gleam@list:map(_pipe@1, gulid:to_string_function()),
    gleam@io:debug(_pipe@2).
